Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1857)

Unified Diff: src/conversions.h

Issue 661275: Added implementation if Uint32::Value. (Closed)
Patch Set: Added IsUint32 Created 10 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/api.cc ('k') | src/conversions-inl.h » ('j') | src/conversions-inl.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/conversions.h
diff --git a/src/conversions.h b/src/conversions.h
index 67f7d53f5177d1613adc4f1ef85d469a9b580e93..bdc7e44a165e8152702c0dd53336ea278e8ab80f 100644
--- a/src/conversions.h
+++ b/src/conversions.h
@@ -32,11 +32,12 @@ namespace v8 {
namespace internal {
// The fast double-to-int conversion routine does not guarantee
// rounding towards zero.
// The result is unspecified if x is infinite or NaN, or if the rounded
// integer value is outside the range of type int.
static inline int FastD2I(double x);
+static inline unsigned int FastD2UI(double x);
static inline double FastI2D(int x) {
« no previous file with comments | « src/api.cc ('k') | src/conversions-inl.h » ('j') | src/conversions-inl.h » ('J')
@@ -32,11 +32,12 @@ namespace v8 {
namespace internal {
-// The fast double-to-int conversion routine does not guarantee
+// The fast double-to-(unsigned-)int conversion routine does not guarantee
// rounding towards zero.
// The result is unspecified if x is infinite or NaN, or if the rounded

Powered by Google App Engine
This is Rietveld 408576698